@@ -33,7 +33,7 @@ from greedyFAS.mainFAS import greedyFAS
 
 
 def get_options():
-    version = '1.5.3'
+    version = '1.5.5'
     parser = argparse.ArgumentParser(description='You are running FAS version ' + str(version) + '.',
                                      epilog="This script allows you to assess the complexity (number of paths) of the "
                                             "feature architecture for linearization.")
@@ -65,13 +65,15 @@ def get_options():
 def main():
     args = get_options()
     clan_dict = {}
-    pathconfigfile = os.path.realpath(__file__).replace('calcFAS.py', 'pathconfig.txt')
+    pathconfigfile = os.path.realpath(__file__).replace('complexityFAS.py', 'pathconfig.txt')
+    option_dict = {}
     with open(pathconfigfile) as f:
         toolpath = f.readline().strip()
     if args.featuretypes is not None:
-        option_dict = fasInput.featuretypes(args.featuretypes, {})
+        option_dict['input_linearized'], option_dict['input_normal'] = fasInput.featuretypes(args.featuretypes)
     else:
-        option_dict = fasInput.featuretypes(toolpath + '/' + 'annoTools.txt', {})
+        option_dict['input_linearized'], option_dict['input_normal'] = fasInput.featuretypes(toolpath + '/'
+                                                                                             + 'annoTools.txt')
     option_dict["max_overlap"] = args.max_overlap
     if 0.0 <= float(args.max_overlap_percentage) <= 1.0:
         option_dict["max_overlap_percentage"] = float(args.max_overlap_percentage)
@@ -86,6 +88,7 @@ def main():
         proteins = args.id
     else:
         proteins = list(proteome.keys())
+    print('Protein ID\t#Paths\tapproximate greedy complexity')
     for protein in proteins:
         calc_complex(protein, proteome, option_dict, clan_dict, args)
 
@@ -95,11 +98,23 @@ def calc_complex(protein, proteome, option, clan_dict, args):
         protein, proteome, clan_dict, option)
     graph, path_number = fasPathing.pb_region_paths(fasPathing.pb_region_mapper(
         lin_set, features, option["max_overlap"], option["max_overlap_percentage"]))
-    print(protein + "\t" + str(path_number))
+    greedy_comp = approx_greedy_comp(graph)
+    print(protein + "\t" + str(path_number) + '\t' + str(greedy_comp))
     if args.show_graph:
         show_graph(graph)
 
 
+def approx_greedy_comp(graph):
+    node = 'START'
+    complexity = 0
+    while not node == 'END':
+        complexity += len(graph[node])
+        node = graph[node][0]
+    return complexity
+
+
+
+
 def show_graph(graph):
     dot = Digraph(comment='feature graph')
     for feature in graph:
